@@ -2,15 +2,15 @@
 Handles CLI interactions for bash2gitlab
 
 usage: bash2gitlab [-h] [--version]
-                   {compile,shred,detect-drift,copy2local,init,map-deploy,commit-map,clean,lint,install-precommit,uninstall-precommit}
+                   {compile,decompile,detect-drift,copy2local,init,map-deploy,commit-map,clean,lint,install-precommit,uninstall-precommit}
                    ...
 
 A tool for making development of centralized yaml gitlab templates more pleasant.
 
 positional arguments:
-  {compile,shred,detect-drift,copy2local,init,map-deploy,commit-map,clean,lint,install-precommit,uninstall-precommit}
+  {compile,decompile,detect-drift,copy2local,init,map-deploy,commit-map,clean,lint,install-precommit,uninstall-precommit}
     compile               Compile an uncompiled directory into a standard GitLab CI structure.
-    shred                 Shred a GitLab CI file, extracting inline scripts into separate .sh files.
+    decompile                 Decompile a GitLab CI file, extracting inline scripts into separate .sh files.
     detect-drift          Detect if generated files have been edited and display what the edits are.
     copy2local            Copy folder(s) from a repo to local, for testing bash in the dependent repo
     init                  Initialize a new bash2gitlab project and config file.
@@ -39,27 +39,29 @@ import argcomplete
 
 from bash2gitlab import __about__
 from bash2gitlab import __doc__ as root_doc
-from bash2gitlab.commands import precommit
 from bash2gitlab.commands.clean_all import clean_targets
 from bash2gitlab.commands.clone2local import clone_repository_ssh, fetch_repository_archive
 from bash2gitlab.commands.compile_all import run_compile_all
+from bash2gitlab.commands.decompile_all import run_decompile_gitlab_file, run_decompile_gitlab_tree
 from bash2gitlab.commands.detect_drift import run_detect_drift
 from bash2gitlab.commands.doctor import run_doctor
 from bash2gitlab.commands.graph_all import generate_dependency_graph
-from bash2gitlab.commands.init_project import create_config_file, prompt_for_config
+from bash2gitlab.commands.init_project import run_init
 from bash2gitlab.commands.lint_all import lint_output_folder, summarize_results
 from bash2gitlab.commands.map_commit import run_commit_map
-from bash2gitlab.commands.map_deploy import get_deployment_map, run_map_deploy
+from bash2gitlab.commands.map_deploy import run_map_deploy
+from bash2gitlab.commands.precommit import PrecommitHookError, install, uninstall
 from bash2gitlab.commands.show_config import run_show_config
-from bash2gitlab.commands.shred_all import run_shred_gitlab_file, run_shred_gitlab_tree
 from bash2gitlab.config import config
 from bash2gitlab.plugins import get_pm
 from bash2gitlab.utils.cli_suggestions import SmartParser
 from bash2gitlab.utils.logging_config import generate_config
 from bash2gitlab.utils.update_checker import check_for_updates
-from bash2gitlab.utils.utils import short_path
 from bash2gitlab.watch_files import start_watch
 
+# emoji support
+sys.stdout.reconfigure(encoding="utf-8")  # type: ignore[union-attr]
+
 logger = logging.getLogger(__name__)
 
 
@@ -75,10 +77,7 @@ def clean_handler(args: argparse.Namespace) -> int:
     return 0
 
 
-essential_gitlab_args_help = (
-    "GitLab connection options. For private instances require --gitlab-url and possibly --token. "
-    "Use --project-id for project-scoped lint when your config relies on includes or project context."
-)
+essential_gitlab_args_help = "GitLab connection options. For private instances require --gitlab-url and possibly --token. Use --project-id for project-scoped lint when your config relies on includes or project context."
 
 
 def lint_handler(args: argparse.Namespace) -> int:
@@ -116,25 +115,17 @@ def lint_handler(args: argparse.Namespace) -> int:
         logger.error("Unexpected error during lint: %s", e)
         return 1
 
-    ok, fail = summarize_results(results)
+    _ok, fail = summarize_results(results)
     return 0 if fail == 0 else 2
 
 
 def init_handler(args: argparse.Namespace) -> int:
     """Handles the `init` command logic."""
     logger.info("Starting interactive project initializer...")
-    base_path = Path(args.directory).resolve()
-
-    if not base_path.exists():
-        base_path.mkdir(parents=True)
-        logger.info(f"Created project directory: {short_path(base_path)}")
-    elif (base_path / "bash2gitlab.toml").exists():
-        logger.error(f"A 'bash2gitlab.toml' file already exists in '{short_path(base_path)}'. Aborting.")
-        return 1
-
+    directory = args.directory
+    force = args.force
     try:
-        user_config = prompt_for_config()
-        create_config_file(base_path, user_config, args.dry_run)
+        run_init(directory, force)
     except (KeyboardInterrupt, EOFError):
         logger.warning("\nInitialization cancelled by user.")
         return 1
@@ -165,6 +156,7 @@ def compile_handler(args: argparse.Namespace) -> int:
     in_dir = Path(args.input_dir).resolve()
     out_dir = Path(args.output_dir).resolve()
     dry_run = bool(args.dry_run)
+    force = bool(args.force)
     parallelism = args.parallelism
 
     if args.watch:
@@ -178,10 +170,7 @@ def compile_handler(args: argparse.Namespace) -> int:
 
     try:
         run_compile_all(
-            uncompiled_path=in_dir,
-            output_path=out_dir,
-            dry_run=dry_run,
-            parallelism=parallelism,
+            uncompiled_path=in_dir, output_path=out_dir, dry_run=dry_run, parallelism=parallelism, force=force
         )
 
         logger.info("✅ GitLab CI processing complete.")
@@ -201,9 +190,9 @@ def drift_handler(args: argparse.Namespace) -> int:
     return 0
 
 
-def shred_handler(args: argparse.Namespace) -> int:
-    """Handler for the 'shred' command (file *or* folder)."""
-    logger.info("Starting bash2gitlab shredder...")
+def decompile_handler(args: argparse.Namespace) -> int:
+    """Handler for the 'decompile' command (file *or* folder)."""
+    logger.info("Starting bash2gitlab decompiler...")
 
     out_dir = Path(args.output_dir).resolve()
     out_dir.mkdir(parents=True, exist_ok=True)  # force folder semantics
@@ -212,7 +201,7 @@ def shred_handler(args: argparse.Namespace) -> int:
 
     try:
         if args.input_file:
-            jobs, scripts, out_yaml = run_shred_gitlab_file(
+            jobs, scripts, out_yaml = run_decompile_gitlab_file(
                 input_yaml_path=Path(args.input_file).resolve(),
                 output_dir=out_dir,
                 dry_run=dry_run,
@@ -223,7 +212,7 @@ def shred_handler(args: argparse.Namespace) -> int:
                 logger.info("✅ Processed %s jobs and created %s script(s).", jobs, scripts)
                 logger.info("Modified YAML written to: %s", out_yaml)
         else:
-            yml_count, jobs, scripts = run_shred_gitlab_tree(
+            yml_count, jobs, scripts = run_decompile_gitlab_tree(
                 input_root=Path(args.input_folder).resolve(),
                 output_dir=out_dir,
                 dry_run=dry_run,
@@ -250,9 +239,8 @@ def shred_handler(args: argparse.Namespace) -> int:
 
 def commit_map_handler(args: argparse.Namespace) -> int:
     """Handler for the 'commit-map' command."""
-    pyproject_path = Path(args.pyproject_path)
     try:
-        mapping = get_deployment_map(pyproject_path)
+        mapping = config.map_folders
     except FileNotFoundError as e:
         logger.error(f"❌ {e}")
         return 10
@@ -266,9 +254,8 @@ def commit_map_handler(args: argparse.Namespace) -> int:
 
 def map_deploy_handler(args: argparse.Namespace) -> int:
     """Handler for the 'map-deploy' command."""
-    pyproject_path = Path(args.pyproject_path)
     try:
-        mapping = get_deployment_map(pyproject_path)
+        mapping = config.map_folders
     except FileNotFoundError as e:
         logger.error(f"❌ {e}")
         return 10
@@ -297,10 +284,10 @@ def install_precommit_handler(args: argparse.Namespace) -> int:
     """
     repo_root = Path(args.repo_root).resolve()
     try:
-        precommit.install(repo_root=repo_root, force=args.force)
+        install(repo_root=repo_root, force=args.force)
         logger.info("Pre-commit hook installed.")
         return 0
-    except precommit.PrecommitHookError as e:
+    except PrecommitHookError as e:
         logger.error("Failed to install pre-commit hook: %s", e)
         return 199
 
@@ -318,10 +305,10 @@ def uninstall_precommit_handler(args: argparse.Namespace) -> int:
     """
     repo_root = Path(args.repo_root).resolve()
     try:
-        precommit.uninstall(repo_root=repo_root, force=args.force)
+        uninstall(repo_root=repo_root, force=args.force)
         logger.info("Pre-commit hook removed.")
         return 0
-    except precommit.PrecommitHookError as e:
+    except PrecommitHookError as e:
         logger.error("Failed to uninstall pre-commit hook: %s", e)
         return 200
 
@@ -387,13 +374,13 @@ def main() -> int:
     compile_parser.add_argument(
         "--in",
         dest="input_dir",
-        required=not bool(config.input_dir),
+        required=not bool(config.compile_input_dir),
         help="Input directory containing the uncompiled `.gitlab-ci.yml` and other sources.",
     )
     compile_parser.add_argument(
         "--out",
         dest="output_dir",
-        required=not bool(config.output_dir),
+        required=not bool(config.compile_output_dir),
         help="Output directory for the compiled GitLab CI files.",
     )
     compile_parser.add_argument(
@@ -408,6 +395,7 @@ def main() -> int:
         action="store_true",
         help="Watch source directories and auto-recompile on changes.",
     )
+    parser.add_argument("--force", action="store_true", help="Force compilation even if no input changes detected")
     add_common_arguments(compile_parser)
     compile_parser.set_defaults(func=compile_handler)
 
@@ -419,44 +407,46 @@ def main() -> int:
     clean_parser.add_argument(
         "--out",
         dest="output_dir",
-        required=not bool(config.output_dir),
+        required=not bool(config.compile_output_dir),
         help="Output directory for the compiled GitLab CI files.",
     )
     add_common_arguments(clean_parser)
     clean_parser.set_defaults(func=clean_handler)
 
-    # --- Shred Command ---
-    shred_parser = subparsers.add_parser(
-        "shred",
-        help="Shred GitLab CI YAML: extract scripts/variables to .sh and rewrite YAML.",
+    # --- Decompile Command ---
+    decompile_parser = subparsers.add_parser(
+        "decompile",
+        help="Decompile GitLab CI YAML: extract scripts/variables to .sh and rewrite YAML.",
         description=(
-            "Use either --in-file (single YAML) or --in-folder (process tree).\n"
-            "--out must be a directory; output YAML and scripts are written side-by-side."
+            "Use either --in-file (single YAML) or --in-folder (process tree).\n--out must be a directory; output YAML and scripts are written side-by-side."
         ),
     )
 
-    group = shred_parser.add_mutually_exclusive_group(required=True)
+    group = decompile_parser.add_mutually_exclusive_group(required=True)
     group.add_argument(
         "--in-file",
+        default=config.decompile_input_file,
         dest="input_file",
-        help="Input GitLab CI YAML file to shred (e.g., .gitlab-ci.yml).",
+        help="Input GitLab CI YAML file to decompile (e.g., .gitlab-ci.yml).",
     )
     group.add_argument(
         "--in-folder",
+        default=config.decompile_input_folder,
         dest="input_folder",
-        help="Folder to recursively shred (*.yml, *.yaml).",
+        help="Folder to recursively decompile (*.yml, *.yaml).",
     )
 
-    shred_parser.add_argument(
+    decompile_parser.add_argument(
         "--out",
         dest="output_dir",
-        required=True,
+        default=config.decompile_output_dir,
+        required=not bool(config.decompile_output_dir),
         help="Output directory (will be created). YAML and scripts are written here.",
     )
 
-    add_common_arguments(shred_parser)
+    add_common_arguments(decompile_parser)
 
-    shred_parser.set_defaults(func=shred_handler)
+    decompile_parser.set_defaults(func=decompile_handler)
 
     # detect drift command
     detect_drift_parser = subparsers.add_parser(
@@ -471,37 +461,42 @@ def main() -> int:
     detect_drift_parser.set_defaults(func=drift_handler)
 
     # --- copy2local Command ---
-    clone_parser = subparsers.add_parser(
+    copy2local_parser = subparsers.add_parser(
         "copy2local",
         help="Copy folder(s) from a repo to local, for testing bash in the dependent repo",
     )
-    clone_parser.add_argument(
+    copy2local_parser.add_argument(
         "--repo-url",
+        default=config.copy2local_repo_url,
         required=True,
         help="Repository URL to copy.",
     )
-    clone_parser.add_argument(
+    copy2local_parser.add_argument(
         "--branch",
+        default=config.copy2local_branch,
         required=True,
         help="Branch to copy.",
     )
-    clone_parser.add_argument(
+    copy2local_parser.add_argument(
         "--copy-dir",
+        default=config.copy2local_copy_dir,
         required=True,
         help="Destination directory for the copy.",
     )
-    clone_parser.add_argument(
+    copy2local_parser.add_argument(
         "--source-dir",
+        default=config.copy2local_source_dir,
         required=True,
         help="Directory to include in the copy.",
     )
-    add_common_arguments(clone_parser)
-    clone_parser.set_defaults(func=clone2local_handler)
+    add_common_arguments(copy2local_parser)
+    copy2local_parser.set_defaults(func=clone2local_handler)
 
+    # Init Parser
     # Init Parser
     init_parser = subparsers.add_parser(
         "init",
-        help="Initialize a new bash2gitlab project and config file.",
+        help="Initialize a new bash2gitlab project in pyproject.toml.",
     )
     init_parser.add_argument(
         "directory",
@@ -509,8 +504,13 @@ def main() -> int:
         default=".",
         help="The directory to initialize the project in. Defaults to the current directory.",
     )
+    init_parser.add_argument(
+        "--force",
+        action="store_true",
+        help="Overwrite an existing [tool.bash2gitlab] section in pyproject.toml.",
+    )
     add_common_arguments(init_parser)
-    init_parser.set_defaults(func=init_handler)
+    init_parser.set_defaults(func=init_handler)  # Changed from init_handler to run_init
 
     # --- map-deploy Command ---
     map_deploy_parser = subparsers.add_parser(
@@ -535,8 +535,7 @@ def main() -> int:
     commit_map_parser = subparsers.add_parser(
         "commit-map",
         help=(
-            "Copy changed files from deployed directories back to their source"
-            " locations based on a mapping in pyproject.toml."
+            "Copy changed files from deployed directories back to their source locations based on a mapping in pyproject.toml."
         ),
     )
     commit_map_parser.add_argument(
@@ -571,8 +570,8 @@ def main() -> int:
     )
     lint_parser.add_argument(
         "--gitlab-url",
+        default=config.lint_gitlab_url,
         dest="gitlab_url",
-        required=True,
         help="Base GitLab URL (e.g., https://gitlab.com).",
     )
     lint_parser.add_argument(
@@ -582,33 +581,36 @@ def main() -> int:
     )
     lint_parser.add_argument(
         "--project-id",
+        default=config.lint_project_id,
         dest="project_id",
         type=int,
         help="Project ID for project-scoped lint (recommended for configs with includes).",
     )
     lint_parser.add_argument(
         "--ref",
+        default=config.lint_ref,
         dest="ref",
         help="Git ref to evaluate includes/variables against (project lint only).",
     )
     lint_parser.add_argument(
         "--include-merged-yaml",
+        default=config.lint_include_merged_yaml,
         dest="include_merged_yaml",
         action="store_true",
         help="Return merged YAML from project-scoped lint (slower).",
     )
     lint_parser.add_argument(
         "--parallelism",
+        default=config.lint_parallelism,
         dest="parallelism",
         type=int,
-        default=config.parallelism,
         help="Max concurrent lint requests (default: CPU count, capped to file count).",
     )
     lint_parser.add_argument(
         "--timeout",
         dest="timeout",
         type=float,
-        default=20.0,
+        default=config.lint_timeout or 20,
         help="HTTP timeout per request in seconds (default: 20).",
     )
     add_common_arguments(lint_parser)
@@ -667,7 +669,7 @@ def main() -> int:
     graph_parser.add_argument(
         "--in",
         dest="input_dir",
-        required=not bool(config.input_dir),
+        required=not bool(config.compile_input_dir),
         help="Input directory containing the uncompiled `.gitlab-ci.yml` and other sources.",
     )
     add_common_arguments(graph_parser)
@@ -695,7 +697,7 @@ def main() -> int:
             compile_parser.error("argument --in is required")
         if not args.output_dir:
             compile_parser.error("argument --out is required")
-    elif args.command == "shred":
+    elif args.command == "decompile":
         if hasattr(args, "input_file"):
             args_input_file = args.input_file
         else:
@@ -708,15 +710,15 @@ def main() -> int:
             args_output_dir = args.output_dir
         else:
             args_output_dir = ""
-        args.input_file = args_input_file or config.input_file
+        args.input_file = args_input_file or config.decompile_input_file
         args.input_folder = args_input_folder or config.input_dir
         args.output_dir = args_output_dir or config.output_dir
 
         # Validate required arguments after merging
         if not args.input_file and not args.input_folder:
-            shred_parser.error("argument --input-folder or --input-file is required")
+            decompile_parser.error("argument --input-folder or --input-file is required")
         if not args.output_dir:
-            shred_parser.error("argument --out is required")
+            decompile_parser.error("argument --out is required")
     elif args.command == "clean":
         args.output_dir = args.output_dir or config.output_dir
         if not args.output_dir:
